"""
    EMIL ProductSyncService

    The EMIL ProductSyncService API description  # noqa: E501

    The version of the OpenAPI document: 1.0
    Contact: kontakt@emil.de
    Generated by: https://openapi-generator.tech
"""


import unittest

import eis.product_sync
from eis.product_sync.api.default_api import DefaultApi  # noqa: E501


class TestDefaultApi(unittest.TestCase):
    """DefaultApi unit test stubs"""

    def setUp(self):
        self.api = DefaultApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_check(self):
        """Test case for check

        Health Check  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
