"""
    EMIL ProductSyncService

    The EMIL ProductSyncService API description  # noqa: E501

    The version of the OpenAPI document: 1.0
    Contact: kontakt@emil.de
    Generated by: https://openapi-generator.tech
"""


import unittest

import eis.product_sync
from eis.product_sync.api.tasks_api import TasksApi  # noqa: E501


class TestTasksApi(unittest.TestCase):
    """TasksApi unit test stubs"""

    def setUp(self):
        self.api = TasksApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_task_product_details(self):
        """Test case for get_task_product_details

        Retrieve the Task product details  # noqa: E501
        """
        pass

    def test_get_task_status(self):
        """Test case for get_task_status

        Retrieve the Task status  # noqa: E501
        """
        pass

    def test_list_task_logs(self):
        """Test case for list_task_logs

        List Tasks  # noqa: E501
        """
        pass

    def test_list_tasks(self):
        """Test case for list_tasks

        List Tasks  # noqa: E501
        """
        pass

    def test_start_compare_task(self):
        """Test case for start_compare_task

        Create the compare  # noqa: E501
        """
        pass

    def test_start_copy_task(self):
        """Test case for start_copy_task

        Create the copy  # noqa: E501
        """
        pass

    def test_start_export_task(self):
        """Test case for start_export_task

        Create the export  # noqa: E501
        """
        pass

    def test_start_sync_task(self):
        """Test case for start_sync_task

        Create the sync  # noqa: E501
        """
        pass

    def test_stop_task(self):
        """Test case for stop_task

        Update the stop  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
