"""
    EMIL ProductSyncService

    The EMIL ProductSyncService API description  # noqa: E501

    The version of the OpenAPI document: 1.0
    Contact: kontakt@emil.de
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import eis.product_sync
from eis.product_sync.model.task_class import TaskClass
globals()['TaskClass'] = TaskClass
from eis.product_sync.model.start_compare_task_response_class import StartCompareTaskResponseClass


class TestStartCompareTaskResponseClass(unittest.TestCase):
    """StartCompareTaskResponseClass unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testStartCompareTaskResponseClass(self):
        """Test StartCompareTaskResponseClass"""
        # FIXME: construct object with mandatory attributes with example values
        # model = StartCompareTaskResponseClass()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
