"""
    EMIL ProductSyncService

    The EMIL ProductSyncService API description  # noqa: E501

    The version of the OpenAPI document: 1.0
    Contact: kontakt@emil.de
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import eis.product_sync
from eis.product_sync.model.start_copy_task_request_dto import StartCopyTaskRequestDto


class TestStartCopyTaskRequestDto(unittest.TestCase):
    """StartCopyTaskRequestDto unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testStartCopyTaskRequestDto(self):
        """Test StartCopyTaskRequestDto"""
        # FIXME: construct object with mandatory attributes with example values
        # model = StartCopyTaskRequestDto()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
