"""
    EMIL ProductSyncService

    The EMIL ProductSyncService API description  # noqa: E501

    The version of the OpenAPI document: 1.0
    Contact: kontakt@emil.de
    Generated by: https://openapi-generator.tech
"""


import unittest

import eis.product_sync
from eis.product_sync.api.products_api import ProductsApi  # noqa: E501


class TestProductsApi(unittest.TestCase):
    """ProductsApi unit test stubs"""

    def setUp(self):
        self.api = ProductsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_product(self):
        """Test case for create_product

        Create the product  # noqa: E501
        """
        pass

    def test_create_product_version(self):
        """Test case for create_product_version

        Create the version  # noqa: E501
        """
        pass

    def test_get_environment_info(self):
        """Test case for get_environment_info

        Retrieve the Environment Info  # noqa: E501
        """
        pass

    def test_list_products(self):
        """Test case for list_products

        List Products  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
